Crate encrypt_config

source ·
Contributors Forks Stargazers Issues MIT License LinkedIn


encrypt-config

A rust crate to manage, persist and encrypt your configurations.
Explore the docs »

View Demo · Report Bug · Request Feature

Table of Contents
  1. About The Project
  2. Usage
  3. Roadmap
  4. Contributing
  5. License
  6. Contact
  7. Acknowledgments

About The Project

A rust crate to manage, persist, encrypt configurations.

(back to top)

Built With

  • Rust
  • Keyring

(back to top)

Usage

use encrypt_config::{Config, SecretSource};
use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize, PartialEq, Debug)]
struct Foo(String);

struct SecretSourceImpl;

// impl `SecectSource` trait for `SecretSourceImpl`
impl SecretSource for SecretSourceImpl {
    type Value = Foo;

    // Where the encypted file is. Don't need if turning on `default_config_dir` feature.
    fn path(&self) -> std::path::PathBuf {
        std::path::PathBuf::from("tests").join("secret.conf")
    }
}

let mut config = Config::new("test"); // `test` is the name of rsa private key in OS' secret manager
config.add_secret_source(SecretSourceImpl).unwrap();  // This will read and decrypt the config from local storage. However, it is empty now.

let new_value = Foo("value".to_owned());
let patch = SecretSourceImpl.upgrade("key", &new_value); // `upgrade` will return a `Patch`
patch.apply(&mut config).unwrap(); // No change will happen until the `Patch` is applied
let v: Foo = config.get("key").unwrap();
assert_eq!(v, Foo("value".to_owned()));

For more examples, please refer to the Example or Documentation

(back to top)

Roadmap

  • Enable protobuf instead of json for better performance

See the open issues for a full list of proposed features (and known issues).

(back to top)

Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are greatly appreciated.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag “enhancement”. Don’t forget to give the project a star! Thanks again!

  1. Fork the Project
  2. Create your Feature Branch (git checkout -b feature/AmazingFeature)
  3. Commit your Changes (git commit -m 'Add some AmazingFeature')
  4. Push to the Branch (git push origin feature/AmazingFeature)
  5. Open a Pull Request

(back to top)

License

Distributed under the MIT License. See LICENSE.txt for more information.

(back to top)

Contact

Louis - 836250617@qq.com

Project Link: https://github.com/kingwingfly/encrypt-config

(back to top)

Acknowledgments

  • None

(back to top)

Structs

Enums

Traits

  • A trait for persisted but not encrypted config source.
  • A trait for persisted and encrypted config source.
  • A trait for normal config source that is neither encrypted or persisted.

Type Aliases